import NetFS
import objc
from PyObjCTools.TestSupport import TestCase


class TestNetFS(TestCase):
    def testFunctions(self):
        self.assertResultHasType(
            NetFS.NetFSCFStringtoCString, objc._C_PTR + objc._C_CHAR_AS_TEXT
        )
        self.assertResultIsNullTerminated(NetFS.NetFSCFStringtoCString)



# This file is generated by objective.metadata
#
# Last update: Sun Jun 28 11:03:16 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$ENETFSACCOUNTRESTRICTED@-5999$ENETFSNOAUTHMECHSUPP@-5997$ENETFSNOPROTOVERSSUPP@-5996$ENETFSNOSHARESAVAIL@-5998$ENETFSPWDNEEDSCHANGE@-5045$ENETFSPWDPOLICY@-5046$"""
misc.update(
    {
        "kNetFSMountPathKey": "MountPath",
        "kNAUIOptionNoUI": "NoUI",
        "kNetFSServerDisplayNameKey": "ServerDisplayName",
        "kNetFSAuthorityParamsKey": "AuthorityParams",
        "kNetFSMountFlagsKey": "MountFlags",
        "kNetFSSupportsKerberosKey": "SupportsKerberos",
        "kNetFSMountedMultiUserKey": "MountedMultiUser",
        "kNetFSHostKey": "Host",
        "kNetFSOpenURLMountKey": "OpenURLMount",
        "kNetFSConnectedAsUserKey": "MountedByUser",
        "kNetFSHasPasswordKey": "HasPassword",
        "kNetFSSupportsGuestKey": "SupportsGuest",
        "kNetFSAlreadyMountedKey": "AlreadyMounted",
        "kNAUIOptionAllowUI": "AllowUI",
        "kNetFSMechTypesSupportedKey": "MechTypesSupported",
        "kNetFSMountedByUserKey": "MountedByUser",
        "kNetFSMountedWithAuthenticationInfoKey": "MountedWithAuthenticationInfo",
        "kNetFSAuthenticationInfoKey": "AuthenticationInfo",
        "kNetFSNoMountAuthenticationKey": "NoMountAuthentication",
        "kNetFSPrinterShareKey": "PrinterShare",
        "kNetFSUseKerberosKey": "Kerberos",
        "kNetFSMountAtMountDirKey": "MountAtMountDir",
        "kNAUIOptionForceUI": "ForceUI",
        "kNetFSGetAccessRightsKey": "GetAccessRights",
        "kNetFSPasswordKey": "Password",
        "kNetFSMountedByKerberosKey": "MountedByKerberos",
        "kNetFSSchemeKey": "Scheme",
        "kNetFSConnectedMultiUserKey": "ConnectedMultiUser",
        "kNetFSAccessRightsKey": "AccessRights",
        "kNetFSMountedByGuestKey": "MountedByGuest",
        "kNetFSSoftMountKey": "SoftMount",
        "kNetFSChangePasswordKey": "ChangePassword",
        "kNetFSUseGuestKey": "Guest",
        "kNetFSUseAuthenticationInfoKey": "UseAuthenticationInfo",
        "kNetFSPathKey": "Path",
        "kNetFSSupportsChangePasswordKey": "SupportsChangePassword",
        "kNetFSNoUserPreferencesKey": "NoUserPreferences",
        "kNetFSForceNewSessionKey": "ForceNewSession",
        "kNAUIOptionKey": "UIOption",
        "kNetFSConnectedAsGuestKey": "MountedByGuest",
        "kNetFSConnectedWithAuthenticationInfoKey": "ConnectedWithAuthenticationInfo",
        "kNetFSDisplayNameKey": "DisplayName",
        "kNetFSAlternatePortKey": "AlternatePort",
        "kNetFSAllowLoopbackKey": "AllowLoopback",
        "kNetFSMountedURLKey": "MountedURL",
        "kNetFSGuestOnlyKey": "GuestOnly",
        "kNetFSAllowSubMountsKey": "AllowSubMounts",
        "kNetFSUserNameKey": "UserName",
        "kNetFSIsHiddenKey": "IsHidden",
    }
)
functions = {
    "NetFSMountURLProbe": (b"^{__CFString=}^{__CFString=}",),
    "NetFSMountURLAsync": (
        b"i^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFDictionary=}^{__CFDictionary=}^^v@@?",
        "",
        {
            "arguments": {
                8: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "i"},
                            2: {"type": "^v"},
                            3: {"type": "@"},
                        },
                    }
                },
                6: {"type_modifier": "o"},
            }
        },
    ),
    "NetFSMountURLSync": (
        b"i^{__CFURL=}^{__CFURL=}^{__CFString=}^{__CFString=}^{__CFDictionary=}^{__CFDictionary=}^^{__CFArray=}",
        "",
        {"arguments": {6: {"type_modifier": "o"}}},
    ),
    "NetFSMountURLCancel": (b"i^v",),
    "NetFSCopyURLForRemountingVolume": (
        b"^{__CFURL=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "NetFSCFStringtoCString": (
        b"^t^{__CFString=}",
        "",
        {"retval": {"c_array_delimited_by_null": True}},
    ),
}
expressions = {}

# END OF FILE



import NetFS
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestNetFS(TestCase):
    def testConstants(self):
        self.assertEqual(NetFS.kNetFSAuthenticationInfoKey, "AuthenticationInfo")
        self.assertEqual(NetFS.kNetFSServerDisplayNameKey, "ServerDisplayName")
        self.assertEqual(
            NetFS.kNetFSSupportsChangePasswordKey, "SupportsChangePassword"
        )
        self.assertEqual(NetFS.kNetFSSupportsGuestKey, "SupportsGuest")
        self.assertEqual(NetFS.kNetFSSupportsKerberosKey, "SupportsKerberos")
        self.assertEqual(NetFS.kNetFSGuestOnlyKey, "GuestOnly")
        self.assertEqual(NetFS.kNetFSNoMountAuthenticationKey, "NoMountAuthentication")
        self.assertEqual(
            NetFS.kNetFSConnectedWithAuthenticationInfoKey,
            "ConnectedWithAuthenticationInfo",
        )
        self.assertEqual(NetFS.kNetFSConnectedAsUserKey, "MountedByUser")
        self.assertEqual(NetFS.kNetFSConnectedAsGuestKey, "MountedByGuest")
        self.assertEqual(NetFS.kNetFSConnectedMultiUserKey, "ConnectedMultiUser")
        self.assertEqual(NetFS.kNetFSMechTypesSupportedKey, "MechTypesSupported")
        self.assertEqual(NetFS.kNAUIOptionKey, "UIOption")
        self.assertEqual(NetFS.kNAUIOptionNoUI, "NoUI")
        self.assertEqual(NetFS.kNAUIOptionAllowUI, "AllowUI")
        self.assertEqual(NetFS.kNAUIOptionForceUI, "ForceUI")
        self.assertEqual(NetFS.kNetFSSchemeKey, "Scheme")
        self.assertEqual(NetFS.kNetFSHostKey, "Host")
        self.assertEqual(NetFS.kNetFSAlternatePortKey, "AlternatePort")
        self.assertEqual(NetFS.kNetFSAuthorityParamsKey, "AuthorityParams")
        self.assertEqual(NetFS.kNetFSUserNameKey, "UserName")
        self.assertEqual(NetFS.kNetFSPasswordKey, "Password")
        self.assertEqual(NetFS.kNetFSPathKey, "Path")
        self.assertEqual(NetFS.kNetFSNoUserPreferencesKey, "NoUserPreferences")
        self.assertEqual(NetFS.kNetFSForceNewSessionKey, "ForceNewSession")
        self.assertEqual(NetFS.kNetFSUseAuthenticationInfoKey, "UseAuthenticationInfo")
        self.assertEqual(NetFS.kNetFSUseGuestKey, "Guest")
        self.assertEqual(NetFS.kNetFSChangePasswordKey, "ChangePassword")
        self.assertEqual(NetFS.kNetFSAllowLoopbackKey, "AllowLoopback")
        self.assertEqual(NetFS.kNetFSUseKerberosKey, "Kerberos")
        self.assertEqual(
            NetFS.kNetFSMountedWithAuthenticationInfoKey,
            "MountedWithAuthenticationInfo",
        )
        self.assertEqual(NetFS.kNetFSMountedByUserKey, "MountedByUser")
        self.assertEqual(NetFS.kNetFSMountedByGuestKey, "MountedByGuest")
        self.assertEqual(NetFS.kNetFSMountedMultiUserKey, "MountedMultiUser")
        self.assertEqual(NetFS.kNetFSMountedByKerberosKey, "MountedByKerberos")
        self.assertEqual(NetFS.ENETFSPWDNEEDSCHANGE, -5045)
        self.assertEqual(NetFS.ENETFSPWDPOLICY, -5046)
        self.assertEqual(NetFS.ENETFSACCOUNTRESTRICTED, -5999)
        self.assertEqual(NetFS.ENETFSNOSHARESAVAIL, -5998)
        self.assertEqual(NetFS.ENETFSNOAUTHMECHSUPP, -5997)
        self.assertEqual(NetFS.ENETFSNOPROTOVERSSUPP, -5996)
        self.assertEqual(NetFS.kNetFSGetAccessRightsKey, "GetAccessRights")
        self.assertEqual(NetFS.kNetFSAlreadyMountedKey, "AlreadyMounted")
        self.assertEqual(NetFS.kNetFSMountPathKey, "MountPath")
        self.assertEqual(NetFS.kNetFSHasPasswordKey, "HasPassword")
        self.assertEqual(NetFS.kNetFSIsHiddenKey, "IsHidden")
        self.assertEqual(NetFS.kNetFSPrinterShareKey, "PrinterShare")
        self.assertEqual(NetFS.kNetFSAccessRightsKey, "AccessRights")
        self.assertEqual(NetFS.kNetFSDisplayNameKey, "DisplayName")
        self.assertEqual(NetFS.kNetFSPasswordKey, "Password")
        self.assertEqual(NetFS.kNetFSSoftMountKey, "SoftMount")
        self.assertEqual(NetFS.kNetFSMountFlagsKey, "MountFlags")
        self.assertEqual(NetFS.kNetFSAllowSubMountsKey, "AllowSubMounts")
        self.assertEqual(NetFS.kNetFSMountAtMountDirKey, "MountAtMountDir")
        self.assertEqual(NetFS.kNetFSOpenURLMountKey, "OpenURLMount")
        self.assertEqual(NetFS.kNetFSMountedURLKey, "MountedURL")

    @min_os_level("10.8")
    def testFunctions10_8(self):
        self.assertArgIsOut(NetFS.NetFSMountURLSync, 6)

        NetFSMountURLBlock = b"vi^v@"

        self.assertArgIsOut(NetFS.NetFSMountURLAsync, 6)
        self.assertArgIsBlock(NetFS.NetFSMountURLAsync, 8, NetFSMountURLBlock)

        NetFS.NetFSMountURLCancel

    @min_os_level("10.9")
    def testFunctions10_9(self):
        NetFS.NetFSMountURLProbe

    @min_os_level("10.10")
    def testFunctions10_10(self):
        self.assertResultIsCFRetained(NetFS.NetFSCopyURLForRemountingVolume)



import NetFS
from PyObjCTools.TestSupport import TestCase


class TestNetFS(TestCase):
    def testStructs(self):
        self.assertNotHasAttr(NetFS, "NetFSMountInterface_V1")
        self.assertNotHasAttr(NetFS, "NetFSInterface")

    def testFunctions(self):
        self.assertNotHasAttr(NetFS, "NetFSInterface_AddRef")
        self.assertNotHasAttr(NetFS, "NetFSInterface_Release")
        self.assertNotHasAttr(NetFS, "NetFS_CreateInterface")
        self.assertNotHasAttr(NetFS, "NetFSQueryInterface")



"""
Python mapping for the NetFS framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from NetFS import _metadata

try:
    long
except NameError:
    long = int

sys.modules["NetFS"] = mod = objc.ObjCLazyModule(
    "NetFS",
    "com.apple.NetFS",
    objc.pathForFramework("/System/Library/Frameworks/NetFS.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (Foundation,),
)


del sys.modules["NetFS._metadata"]
